==> haskell-persistent-sqlite-2.6.2-42-i686.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.6.2
id: persistent-sqlite-2.6.2-KsK64sZFxcpLZzhTApHIeN
key: persistent-sqlite-2.6.2-KsK64sZFxcpLZzhTApHIeN
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Sqlite Database.Persist.Sqlite
abi: 2178e88b4f9e8d3f6b8f0a9d489fb5de
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/persistent-sqlite-2.6.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/persistent-sqlite-2.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/persistent-sqlite-2.6.2
hs-libraries: HSpersistent-sqlite-2.6.2-KsK64sZFxcpLZzhTApHIeN
extra-libraries:
    pthread
depends:
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk base-4.9.1.0
    bytestring-0.10.8.1 conduit-1.2.11-GzxQexWP3ouJXox0rAqJ5D
    containers-0.5.7.1 microlens-th-0.4.1.1-DS5mBQOVXPfALmfN2UZZ6b
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    monad-logger-0.3.25-FthSMO3Vcr8BLZlAcpMdTu
    old-locale-1.0.0.7-KGBP1BSKxH5GCm0LnZP04j
    persistent-2.6.1-9ZWX2RZPfKg1JsAfFKOJLS
    resource-pool-0.2.3.2-GSqOro7tMX19NOYS758Lwr
    resourcet-1.1.9-DJf1ANdxSraDnKUpiOoSOA
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-sqlite-2.6.2-48-i686.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-sqlite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-sqlite
version: 2.6.2
id: persistent-sqlite-2.6.2-HpHn2oGOIUNHaK3QRYbdJi
key: persistent-sqlite-2.6.2-HpHn2oGOIUNHaK3QRYbdJi
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Backend for the persistent library using sqlite3.
description:
    This package includes a thin sqlite3 wrapper based on the direct-sqlite package, as well as the entire C library, so there are no system dependencies.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Sqlite Database.Persist.Sqlite
abi: 0a9a473977d93521b53476942adc0802
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/persistent-sqlite-2.6.2
library-dirs: /usr/lib/ghc-8.0.2/site-local/persistent-sqlite-2.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/persistent-sqlite-2.6.2
hs-libraries: HSpersistent-sqlite-2.6.2-HpHn2oGOIUNHaK3QRYbdJi
extra-libraries:
    pthread
depends:
    aeson-1.2.1.0-LtwtJj4trOg6E4DiroefXf base-4.9.1.0
    bytestring-0.10.8.1 conduit-1.2.11-IZZgx95zXN83i3dNdoRZvV
    containers-0.5.7.1 microlens-th-0.4.1.1-5szUVILkeNp4QYbk6VKas3
    monad-control-1.0.2.2-FLdbJMBsCl8Hxe7Woti7SW
    monad-logger-0.3.25-BU1FP4uCHzy2bWs47awxTg
    old-locale-1.0.0.7-KGBP1BSKxH5GCm0LnZP04j
    persistent-2.7.0-ChCYEvEH5nyLJvWe5T6xZp
    resource-pool-0.2.3.2-InRKoCdDIbZGAVcCaYQjyQ
    resourcet-1.1.9-AaZCIqnYF9zJKlT6eUxN1Z
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
haddock-interfaces: /usr/share/doc/haskell-persistent-sqlite/html/persistent-sqlite.haddock
haddock-html: /usr/share/doc/haskell-persistent-sqlite/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
